Deep Inversion Validation Library's documentation
=================================================

This is the documentation of `DIVal <https://github.com/jleuschn/dival>`_, a
library for testing and comparing deep learning based methods for inverse
problems written in python.

To get started, we recommend having a look at the `example scripts
<https://github.com/jleuschn/dival/tree/master/dival/examples>`_.

Below is a list of some fundamental functions and classes.

.. autosummary::
    ~dival.datasets.standard.get_standard_dataset
    ~dival.datasets.dataset.Dataset
    ~dival.reconstructors.reconstructor.Reconstructor
    ~dival.measure.Measure
    ~dival.evaluation.TaskTable

.. toctree::
    :glob:
    :maxdepth: 3
    :caption: Contents:
    
    dival.*
